@@ -85,15 +85,10 @@ class ReportModel:
     @property
     def tests(self):
         mapping = {"SKIP": "warning",
-                   "ABORT": "danger",
                    "ERROR": "danger",
                    "FAIL": "danger",
                    "WARN": "warning",
                    "PASS": "success",
-                   "START": "info",
-                   "ALERT": "danger",
-                   "RUNNING": "info",
-                   "NOSTATUS": "info",
                    "INTERRUPTED": "danger",
                    "CANCEL": "warning"}
         test_info = []
@@ -206,7 +201,8 @@ class HTMLResult(Result):
                          stdout=inout, stderr=inout,
                          preexec_fn=setsid)
 
-    def _render(self, result, output_path):
+    @staticmethod
+    def _render(result, output_path):
         env = jinja.Environment(
             loader=jinja.PackageLoader('avocado_result_html'),
             autoescape=True,
